
:autogenerated:

krotov.functionals module
=========================

.. currentmodule:: krotov.functionals

.. automodule:: krotov.functionals
    :members: chis_re
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Functions:

    .. autosummary::
        :nosignatures:

        chis_re





    ``__all__``: :func:`chis_re <krotov.functionals.chis_re>`



    Reference
    ---------